import { Component, OnInit } from '@angular/core';
import { DomSanitizer, SafeStyle } from '@angular/platform-browser';
import { ActivatedRoute, ActivatedRouteSnapshot, ActivationStart, Data, Router, RoutesRecognized } from '@angular/router';
import { UserModel } from 'src/app/modules/auth/models/user.model';
import { AuthService } from 'src/app/modules/auth/services/auth/auth.service';
import { ProfileTabEnum } from '../../enums/profile-tab.enum';
import { profileTabRoutes } from '../../profile-routing';


interface ProfileTab {
    tab: ProfileTabEnum;
    label: string;
    icon?: string;
}

@Component({
    selector: 'app-profile-edit',
    templateUrl: './profile-edit.component.html',
    styleUrls: ['./profile-edit.component.scss']
})
export class ProfileEditComponent implements OnInit {

    profileTabRoutes = profileTabRoutes;
    currentTabName: string;
    user: UserModel | null = null;
    selectedIndex = 0;
    defaultProfileTab = ProfileTabEnum.Basics;
    tabs: ProfileTab[] = [
        {
            tab: ProfileTabEnum.Basics,
            label: 'PROFILE.BASICS',
            icon: 'fa fa-id-badge',
        },
        {
            tab: ProfileTabEnum.Contact,
            label: 'PROFILE.CONTACT',
            icon: 'fa fa-address-book'
        },
        {
            tab: ProfileTabEnum.Credentials,
            label: 'PROFILE.PASSWORD',
            icon: 'fa fa-unlock-alt',
        },
        {
            tab: ProfileTabEnum.Avatar,
            label: 'PROFILE.AVATAR',
            icon: 'fa fa-picture-o',
        },
        {
            tab: ProfileTabEnum.Settings,
            label: 'PROFILE.SITE_SETTINGS',
            icon: 'fa fa-sliders',
        },
    ];

    constructor(
        private sanitizer: DomSanitizer,
        authService: AuthService,
        private activatedRoute: ActivatedRoute,
        private router: Router,
    ) {
        this.user = authService.getUser();
        authService.userChange.subscribe(user => {
            this.user = user;
        });
        this.onRouteChange(activatedRoute.snapshot.firstChild?.data);
        this.router.events.subscribe(event => {
            if (event instanceof RoutesRecognized) {
                console.log({event});
            }
        });
    }

    onRouteChange(data: Data): void {
        this.currentTabName = undefined;
        if (data?.tab) {
            const tab = data.tab as ProfileTabEnum;
            const tabIndex = this.tabs.findIndex(i => i.tab === tab);
            console.log({tab, tabIndex});
            if (tabIndex !== -1) {
                this.selectedIndex = tabIndex;
                this.currentTabName = this.tabs[tabIndex].label;
            }
        } else {
            const index = this.tabs.findIndex(i => i.tab === this.defaultProfileTab);
            if (index !== -1) {
                this.selectedIndexChange(index);
            }
        }
    }

    selectedIndexChange(index: number): void {
        console.log({index});
        this.selectedIndex = index;
        this.currentTabName = undefined;
        const tab = this.tabs[index];
        if (tab) {
            const route = this.profileTabRoutes.find(i => i.data.tab === tab.tab);
            this.currentTabName = tab.label;
            if (route) {
                this.router.navigate([route.path], {
                    relativeTo: this.activatedRoute,
                });
            }
        }
    }

    ngOnInit(): void {
    }

    url(url: string): SafeStyle {
        return this.sanitizer.bypassSecurityTrustStyle(`url('${url}')`);
    }
}
